@@ -610,7 +610,7 @@ class PlotAstroData(AstroFrame):
 
     def add_scalebar(self, length: float = 0, label: str = '',
                      color: str = 'gray', barpos: tuple[float, float] = (0.8, 0.12),
-                     fontsize: float = None, linewidth: float = 3,
+                     fontsize: float | None = None, linewidth: float = 3,
                      bbox: dict = {'alpha': 0}) -> None:
         """Use Axes.text and Axes.plot of matplotlib.
 
@@ -622,8 +622,8 @@ class PlotAstroData(AstroFrame):
             fontsize (float, optional): None means 15 if one channel else 20. Defaults to None.
             linewidth (float, optional): Width of the bar. Defaults to 3.
         """
-        if length == 0 or label == '':
-            print('Please input length and label.')
+        if length == 0:
+            print('Please input length to add_scalebar().')
             return
         if fontsize is None:
             fontsize = 20 if len(self.ax) == 1 else 15
@@ -857,16 +857,16 @@ class PlotAstroData(AstroFrame):
             print('RGB shapes mismatch. Skip add_rgb.')
             return
 
-        for i in range(3):
-            c[i] = (c[i] - _kw['vmin'][i]) \
-                   / (_kw['vmax'][i] - _kw['vmin'][i]) * 255
+        for i, (cmin, cmax) in enumerate(zip(_kw['vmin'], _kw['vmax'])):
+            if cmax > cmin:
+                c[i] = (c[i] - cmin) / (cmax - cmin) * 255
             c[i] = self.vskipfill(c[i], v)
-        size = np.shape(c[0][0])
-        for axnow, red, green, blue in zip(self.ax, *c):
-            im = Image.new('RGB', size[::-1], (128, 128, 128))
-            rgb = [red[::-1, :], green[::-1, :], blue[::-1, :]]
-            for j in range(size[0]):
-                for i in range(size[1]):
+        size = np.shape(c[0][0])[::-1]
+        c = np.moveaxis(c, 1, 0)[:, :, ::-self.ydir, ::-self.xdir]
+        for axnow, rgb in zip(self.ax, c):
+            im = Image.new('RGB', size, (128, 128, 128))
+            for j in range(size[1]):
+                for i in range(size[0]):
                     value = tuple(int(a[j, i]) for a in rgb)
                     im.putpixel((i, j), value)
             axnow.imshow(im, extent=[x[0], x[-1], y[0], y[-1]])
